pub struct AggregateEntry {
pub provider: Option<String>,
pub service: Option<String>,
pub resources: Option<Vec<ResourceEntry>>,
/* private fields */
}Fields
provider: Option<String>service: Option<String>resources: Option<Vec<ResourceEntry>>Trait Implementations
Sourceimpl Clone for AggregateEntry
impl Clone for AggregateEntry
Sourcefn clone(&self) -> AggregateEntry
fn clone(&self) -> AggregateEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregateEntry
impl Debug for AggregateEntry
Sourceimpl<D: ResourceDialect> Decode<AggregateEntry, D> for AggregateEntry
impl<D: ResourceDialect> Decode<AggregateEntry, D> for AggregateEntry
Sourceimpl Default for AggregateEntry
impl Default for AggregateEntry
Sourcefn default() -> AggregateEntry
fn default() -> AggregateEntry
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<AggregateEntry, D> for &AggregateEntry
impl<D: ResourceDialect> Encode<AggregateEntry, D> for &AggregateEntry
Sourceimpl PartialEq for AggregateEntry
impl PartialEq for AggregateEntry
Sourcefn eq(&self, other: &AggregateEntry) -> bool
fn eq(&self, other: &AggregateEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for AggregateEntry
impl StructuralPartialEq for AggregateEntry
Sourceimpl TypeMarker for AggregateEntry
impl TypeMarker for AggregateEntry
Sourcetype Owned = AggregateEntry
type Owned = AggregateEntry
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for AggregateEntry
impl ValueTypeMarker for AggregateEntry
Sourcetype Borrowed<'a> = &'a AggregateEntry
type Borrowed<'a> = &'a AggregateEntry
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for AggregateEntry
impl RefUnwindSafe for AggregateEntry
impl Send for AggregateEntry
impl Sync for AggregateEntry
impl Unpin for AggregateEntry
impl UnsafeUnpin for AggregateEntry
impl UnwindSafe for AggregateEntry